@@ -27,6 +27,7 @@
 #include "device-provider.h"
 #include "notifier.h"
 #include "service.h"
+#include "utils.h"
 
 #define BUS_NAME "org.ayatana.indicator.power"
 #define BUS_PATH "/org/ayatana/indicator/power"
@@ -791,57 +792,12 @@ create_menu (IndicatorPowerService * self, int profile)
 ****  GActions
 ***/
 
-/* Run a particular program based on an activation */
-static void
-execute_command (const gchar * cmd)
-{
-  GError * err = NULL;
-
-  g_debug ("Issuing command '%s'", cmd);
-
-  if (!g_spawn_command_line_async (cmd, &err))
-    {
-      g_warning ("Unable to start %s: %s", cmd, err->message);
-      g_error_free (err);
-    }
-}
-
 static void
 on_settings_activated (GSimpleAction * a      G_GNUC_UNUSED,
                        GVariant      * param  G_GNUC_UNUSED,
                        gpointer        gself  G_GNUC_UNUSED)
 {
-  static const gchar *control_center_cmd = NULL;
-
-  if (control_center_cmd == NULL)
-    {
-      if ((!g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "xubuntu")) || (!g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "xfce")))
-        {
-          control_center_cmd = "xfce4-power-manager-settings";
-        }
-      else if (!g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "mate"))
-        {
-          control_center_cmd = "mate-power-preferences";
-        }
-      else if (!g_strcmp0 (g_getenv ("XDG_CURRENT_DESKTOP"), "Pantheon"))
-        {
-          control_center_cmd = "switchboard --open-plug system-pantheon-power";
-        }
-      else
-        {
-          gchar *path;
-
-          path = g_find_program_in_path ("unity-control-center");
-          if (path != NULL)
-            control_center_cmd = "unity-control-center power";
-          else
-            control_center_cmd = "gnome-control-center power";
-
-          g_free (path);
-        }
-    }
-
-  execute_command (control_center_cmd);
+  utils_handle_settings_request();
 }
 
 static void
@@ -849,7 +805,14 @@ on_statistics_activated (GSimpleAction * a      G_GNUC_UNUSED,
                          GVariant      * param,
                          gpointer        gself  G_GNUC_UNUSED)
 {
-  if (!g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "mate"))
+  if (is_mate())
+    {
+      char *cmd = g_strconcat ("mate-power-statistics", " --device ",
+                               g_variant_get_string (param, NULL), NULL);
+      execute_command (cmd);
+      g_free (cmd);
+    }
+  else if (is_gnome() || is_unity())
     {
       char *cmd = g_strconcat ("gnome-power-statistics", " --device ",
                                g_variant_get_string (param, NULL), NULL);
@@ -858,13 +821,20 @@ on_statistics_activated (GSimpleAction * a      G_GNUC_UNUSED,
     }
   else
     {
-      char *cmd = g_strconcat ("gnome-power-statistics", " --device ",
-                               g_variant_get_string (param, NULL), NULL);
-      execute_command (cmd);
-      g_free (cmd);
+      zenity_warning ("dialog-warning",
+                      _("Warning"),
+                      _("The Ayatana Power Indicator does not support evoking the\npower statistics application your desktop environment, yet.\n\nPlease report this to the developers at:\nhttps://github.com/ArcticaProject/ayatana-indicator-power/issues"));
     }
 }
 
+static void
+on_phone_settings_activated (GSimpleAction * a      G_GNUC_UNUSED,
+                             GVariant      * param  G_GNUC_UNUSED,
+                             gpointer        gself  G_GNUC_UNUSED)
+{
+    utils_handle_settings_request();
+}
+
 /***
 ****
 ***/
@@ -901,6 +871,7 @@ init_gactions (IndicatorPowerService * self)
 
   GActionEntry entries[] = {
     { "activate-settings", on_settings_activated },
+    { "activate-phone-settings", on_phone_settings_activated },
     { "activate-statistics", on_statistics_activated, "s" }
   };
 
